@@ -1,15 +1,15 @@
 use strict;
 use warnings;
 package Config::INI::Reader;
-BEGIN {
-  $Config::INI::Reader::VERSION = '0.017';
+{
+  $Config::INI::Reader::VERSION = '0.019';
 }
 use Mixin::Linewise::Readers;
 # ABSTRACT: a subclassable .ini-file parser
 
 
 use Carp ();
-use IO::File;
+use IO::File 1.14;
 use IO::String;
 
 our @CARP_NOT = qw(Mixin::Linewise::Readers);
@@ -40,8 +40,7 @@ sub read_handle {
       next;
     }
 
-    my $lineno = $handle->input_line_number;
-    Carp::croak "Syntax error at line $lineno: '$line'";
+    $self->handle_unparsed_line($handle, $line);
   }
 
   $self->finalize;
@@ -104,6 +103,13 @@ sub preprocess_line {
 }
 
 
+sub handle_unparsed_line {
+  my ($self, $handle, $line) = @_;
+  my $lineno = $handle->input_line_number;
+  Carp::croak "Syntax error at line $lineno: '$line'";
+}
+
+
 sub finalize { }
 
 
@@ -127,7 +133,7 @@ Config::INI::Reader - a subclassable .ini-file parser
 
 =head1 VERSION
 
-version 0.017
+version 0.019
 
 =head1 SYNOPSIS
 
@@ -270,6 +276,13 @@ This method is called to preprocess each line after it's read but before it's
 parsed.  The default implementation just strips inline comments.  Alterations
 to the line are made in place.
 
+=head2 handle_unparsed_line
+
+  $reader->handle_unparsed_line( $io, $line );
+
+This method is called when the reader encounters a line that doesn't look like
+anything it recognizes.  By default, it throws an exception.
+
 =head2 finalize
 
   $reader->finalize;
